==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/WARRANTYCLAIMLINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour WARRANTYCLAIMLINEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="WARRANTYCLAIMLINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WARRANTYCLAIMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WARRANTYCLAIMLINEID_Type", propOrder = {
    "warrantyclaimid",
    "activitycode",
    "jobsequence",
    "description"
})
public class WARRANTYCLAIMLINEID_Type {

    @XmlElement(name = "WARRANTYCLAIMID", required = true)
    protected WARRANTYCLAIMID_Type warrantyclaimid;
    @XmlElement(name = "ACTIVITYCODE", required = true)
    protected ACTIVITYCODE activitycode;
    @XmlElement(name = "JOBSEQUENCE")
    protected Long jobsequence;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété warrantyclaimid.
     * 
     * @return
     *     possible object is
     *     {@link WARRANTYCLAIMID_Type }
     *     
     */
    public WARRANTYCLAIMID_Type getWARRANTYCLAIMID() {
        return warrantyclaimid;
    }

    /**
     * Définit la valeur de la propriété warrantyclaimid.
     * 
     * @param value
     *     allowed object is
     *     {@link WARRANTYCLAIMID_Type }
     *     
     */
    public void setWARRANTYCLAIMID(WARRANTYCLAIMID_Type value) {
        this.warrantyclaimid = value;
    }

    /**
     * Obtient la valeur de la propriété activitycode.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public ACTIVITYCODE getACTIVITYCODE() {
        return activitycode;
    }

    /**
     * Définit la valeur de la propriété activitycode.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public void setACTIVITYCODE(ACTIVITYCODE value) {
        this.activitycode = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/WARRANTYCLAIMLINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for WARRANTYCLAIMLINEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="WARRANTYCLAIMLINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WARRANTYCLAIMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "WARRANTYCLAIMLINEID_Type", propOrder = {
    "warrantyclaimid",
    "activitycode",
    "jobsequence",
    "description"
})
public class WARRANTYCLAIMLINEID_Type {

    @XmlElement(name = "WARRANTYCLAIMID", required = true)
    protected WARRANTYCLAIMID_Type warrantyclaimid;
    @XmlElement(name = "ACTIVITYCODE", required = true)
    protected ACTIVITYCODE activitycode;
    @XmlElement(name = "JOBSEQUENCE")
    protected Long jobsequence;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the warrantyclaimid property.
     * 
     * @return
     *     possible object is
     *     {@link WARRANTYCLAIMID_Type }
     *     
     */
    public WARRANTYCLAIMID_Type getWARRANTYCLAIMID() {
        return warrantyclaimid;
    }

    /**
     * Sets the value of the warrantyclaimid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WARRANTYCLAIMID_Type }
     *     
     */
    public void setWARRANTYCLAIMID(WARRANTYCLAIMID_Type value) {
        this.warrantyclaimid = value;
    }

    /**
     * Gets the value of the activitycode property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public ACTIVITYCODE getACTIVITYCODE() {
        return activitycode;
    }

    /**
     * Sets the value of the activitycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYCODE }
     *     
     */
    public void setACTIVITYCODE(ACTIVITYCODE value) {
        this.activitycode = value;
    }

    /**
     * Gets the value of the jobsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Sets the value of the jobsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
